cfg_explain: Explain effective parameters after normalization

View source: R/config.R

cfg_explainR Documentation

Explain effective parameters after normalization

Description

Produces a compact tibble that reports selected effective inputs used by the engine after validation and normalization (see cfg_normalize()).

Usage

cfg_explain(config)

Arguments

config

List configuration (not a file path).

Value

A tibble with selected effective parameters and derived values.

Examples

cfg <- dcf_spec_template()
cfg$acq_price_ht <- 1e6
ex <- cfg_explain(cfg)
str(ex)


cre.dcf documentation built on April 10, 2026, 5:08 p.m.