dcf_spec_template: Minimal specification template for a Discounted Cash Flow...

View source: R/config.R

dcf_spec_templateR Documentation

Minimal specification template for a Discounted Cash Flow (DCF) case

Description

Returns a ready-to-edit list that matches the package's YAML grammar. Use this for interactive prototyping or to generate a YAML file.

Usage

dcf_spec_template()

Value

A named list with all required top-level keys and sane defaults.

Examples

cfg <- dcf_spec_template()
str(cfg, max.level = 1)

cre.dcf documentation built on April 10, 2026, 5:08 p.m.