derive_exit_yield: Derive an exit yield from an entry yield and a spread (bps)

View source: R/utils.R

derive_exit_yieldR Documentation

Derive an exit yield from an entry yield and a spread (bps)

Description

Derive an exit yield from an entry yield and a spread (bps)

Usage

derive_exit_yield(entry_yield, spread_bps)

Arguments

entry_yield

numeric(1) >= 0. Entry cap-rate in decimal form.

spread_bps

numeric(1). Spread in basis points (may be negative).

Value

numeric(1) Exit yield in decimal form.

Examples

derive_exit_yield(0.055, 50) # 0.060


cre.dcf documentation built on April 10, 2026, 5:08 p.m.