| cfg_explain | R Documentation |
Produces a compact tibble that reports selected effective inputs used by the
engine after validation and normalization (see cfg_normalize()).
cfg_explain(config)
config |
List configuration (not a file path). |
A tibble with selected effective parameters and derived values.
cfg <- dcf_spec_template()
cfg$acq_price_ht <- 1e6
ex <- cfg_explain(cfg)
str(ex)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.